==> apache_superset-4.1.3-source.tar.gz: apache_superset-4.1.3rc2/superset-frontend/src/components/FacePile/FacePile.stories.tsx <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import FacePile from '.';

export default {
  title: 'FacePile',
  component: FacePile,
  argTypes: {
    maxCount: { control: 'number', defaultValue: 4 },
  },
};

const firstNames = [
  'James',
  'Mary',
  'John',
  'Patricia',
  'Mohamed',
  'Venkat',
  'Lao',
  'Robert',
  'Jennifer',
  'Michael',
  'Linda',
];
const lastNames = [
  'Smith',
  'Johnson',
  'Williams',
  'Saeed',
  'Jones',
  'Brown',
  'Tzu',
];

const users = [...new Array(10)].map((_, i) => ({
  first_name: firstNames[Math.floor(Math.random() * firstNames.length)],
  last_name: lastNames[Math.floor(Math.random() * lastNames.length)],
  id: i,
}));

export const SupersetFacePile = ({ maxCount }: { maxCount: number }) => (
  <FacePile users={users} maxCount={maxCount} />
);

==> apache_superset-6.0.0-source.tar.gz: apache_superset-6.0.0rc4/superset-frontend/src/components/FacePile/FacePile.stories.tsx <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { FacePile } from '.';

export default {
  title: 'Components/FacePile',
  component: FacePile,
  argTypes: {
    maxCount: { control: 'number', defaultValue: 4 },
  },
};

const firstNames = [
  'James',
  'Mary',
  'John',
  'Patricia',
  'Mohamed',
  'Venkat',
  'Lao',
  'Robert',
  'Jennifer',
  'Michael',
  'Linda',
];
const lastNames = [
  'Smith',
  'Johnson',
  'Williams',
  'Saeed',
  'Jones',
  'Brown',
  'Tzu',
];

const users = [...new Array(10)].map((_, i) => ({
  first_name: firstNames[Math.floor(Math.random() * firstNames.length)],
  last_name: lastNames[Math.floor(Math.random() * lastNames.length)],
  id: i,
}));

export const SupersetFacePile = ({ maxCount }: { maxCount: number }) => (
  <FacePile users={users} maxCount={maxCount} />
);
